/*
 * Copyright (C)2005-2019 Haxe Foundation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package sys.net;

/**
	A UDP socket class
**/
class UdpSocket extends Socket {
	public function new() {
		throw "Not available on this platform";
		super();
	}

	/**
		Allows the socket to send to broadcast addresses.
	**/
	public function setBroadcast(b:Bool):Void {
		throw "Not available on this platform";
	}

	/**
		Sends data to the specified target host/port address.
	**/
	public function sendTo(buf:haxe.io.Bytes, pos:Int, len:Int, addr:Address):Int {
		return 0;
	}

	/**
		Reads data from any incoming address and store the receiver address into the address parameter.
	**/
	public function readFrom(buf:haxe.io.Bytes, pos:Int, len:Int, addr:Address):Int {
		return 0;
	}
}
